@@ -5,6 +5,7 @@ __all__ = ('about', 'about_from_setup')
 
 import sys
 from typing import Any
+from typing_extensions import Self
 from pathlib import Path
 from collections import namedtuple
 from functools import partial
@@ -50,14 +51,19 @@ class adict(dict[str, Any]):
         except KeyError as exc:
             raise AttributeError(*exc.args) from None
 
-    copy = __copy__ = lambda self: self.__class__(self)
+    def __copy__(self) -> Self:
+        return self.__class__(self)
+
+    copy = __copy__
 
 
 def about(package: str | None = None) -> adict:
     pkg_globals = sys._getframe(1).f_globals
     pkg_globals.pop("__builtins__", None)
     pkg_globals.pop("__cached__",   None)
-    if package is None: package = pkg_globals["__package__"]
+    if package is None: package = pkg_globals.get("__package__", None)
+    if package is None:  # pragma: no cover
+        raise ValueError("A distribution name is required.")
     metadata = get_metadata(package)
     version = parse_version(get_version(package))
     project_urls = {item.partition(",")[0].strip():
@@ -116,6 +122,8 @@ def about(package: str | None = None) -> adict:
     pkg_globals.update(pkg_metadata)
     pkg_globals.setdefault("__all__", [])
     pkg_globals["__all__"] += list(pkg_metadata.keys())
+    pkg_metadata = pkg_metadata.copy()
+    pkg_metadata.__metadata__ = dict(metadata.items())  # type: ignore[attr-defined]
     return pkg_metadata
 
 
@@ -204,6 +212,8 @@ def about_from_setup(package_path: Path | str | None = None) -> adict:
     pkg_globals["about"] = pkg_metadata
     pkg_globals.setdefault("__all__", [])
     pkg_globals["__all__"].append("about")
+    pkg_metadata = pkg_metadata.copy()
+    pkg_metadata.__metadata__ = metadata
     return pkg_metadata
 
 
